@@ -5,6 +5,11 @@ import * as fs from "fs-extra";
 import * as Mustache from "mustache";
 import { PackName, RuleMetadata } from "../src/packs/aws-prototyping-rules";
 
+RuleMetadata.forEach((x) => {
+  x.info = x.info.replace("\n\n", "<br /><br />");
+  x.explanation = x.explanation.replace("\n\n", "<br /><br />");
+});
+
 const renderedMarkdown = Mustache.render(
   fs
     .readFileSync(
