@@ -67,19 +67,25 @@ class AwsPrototypingChecks(
     def __init__(
         self,
         *,
+        additional_loggers: typing.Optional[typing.Sequence[_cdk_nag_263d9695.INagLogger]] = None,
         log_ignores: typing.Optional[builtins.bool] = None,
+        report_formats: typing.Optional[typing.Sequence[_cdk_nag_263d9695.NagReportFormat]] = None,
         reports: typing.Optional[builtins.bool] = None,
         suppression_ignore_condition: typing.Optional[_cdk_nag_263d9695.INagSuppressionIgnore] = None,
         verbose: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
-        :param log_ignores: Whether or not to log triggered rules that have been suppressed as informational messages (default: false).
-        :param reports: Whether or not to generate CSV compliance reports for applied Stacks in the App's output directory (default: true).
+        :param additional_loggers: Additional NagLoggers for logging rule validation outputs.
+        :param log_ignores: Whether or not to log suppressed rule violations as informational messages (default: false).
+        :param report_formats: If reports are enabled, the output formats of compliance reports in the App's output directory (default: only CSV).
+        :param reports: Whether or not to generate compliance reports for applied Stacks in the App's output directory (default: true).
         :param suppression_ignore_condition: Conditionally prevent rules from being suppressed (default: no user provided condition).
         :param verbose: Whether or not to enable extended explanatory descriptions on warning, error, and logged ignore messages (default: false).
         '''
         props = _cdk_nag_263d9695.NagPackProps(
+            additional_loggers=additional_loggers,
             log_ignores=log_ignores,
+            report_formats=report_formats,
             reports=reports,
             suppression_ignore_condition=suppression_ignore_condition,
             verbose=verbose,
@@ -249,6 +255,7 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="@aws-prototyping-sdk/pdk-nag.PD
         context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         default_stack_synthesizer: typing.Optional[_aws_cdk_ceddda9d.IReusableStackSynthesizer] = None,
         outdir: typing.Optional[builtins.str] = None,
+        policy_validation_beta1: typing.Optional[typing.Sequence[_aws_cdk_ceddda9d.IPolicyValidationPluginBeta1]] = None,
         post_cli_context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         stack_traces: typing.Optional[builtins.bool] = None,
         tree_metadata: typing.Optional[builtins.bool] = None,
@@ -263,6 +270,7 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="@aws-prototyping-sdk/pdk-nag.PD
         :param context: Additional context values for the application. Context set by the CLI or the ``context`` key in ``cdk.json`` has precedence. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
         :param default_stack_synthesizer: The stack synthesizer to use by default for all Stacks in the App. The Stack Synthesizer controls aspects of synthesis and deployment, like how assets are referenced and what IAM roles to use. For more information, see the README of the main CDK package. Default: - A ``DefaultStackSynthesizer`` with default settings
         :param outdir: The output directory into which to emit synthesized artifacts. You should never need to set this value. By default, the value you pass to the CLI's ``--output`` flag will be used, and if you change it to a different directory the CLI will fail to pick up the generated Cloud Assembly. This property is intended for internal and testing use. Default: - If this value is *not* set, considers the environment variable ``CDK_OUTDIR``. If ``CDK_OUTDIR`` is not defined, uses a temp directory.
+        :param policy_validation_beta1: Validation plugins to run after synthesis. Default: - no validation plugins
         :param post_cli_context: Additional context values for the application. Context provided here has precedence over context set by: - The CLI via --context - The ``context`` key in ``cdk.json`` - The ``AppProps.context`` property This property is recommended over the ``AppProps.context`` property since you can make final decision over which context value to take in your app. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
         :param stack_traces: Include construct creation stack trace in the ``aws:cdk:trace`` metadata key of all constructs. Default: true stack traces are included unless ``aws:cdk:disable-stack-trace`` is set in the context.
         :param tree_metadata: Include construct tree metadata as part of the Cloud Assembly. Default: true
@@ -276,6 +284,7 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="@aws-prototyping-sdk/pdk-nag.PD
             context=context,
             default_stack_synthesizer=default_stack_synthesizer,
             outdir=outdir,
+            policy_validation_beta1=policy_validation_beta1,
             post_cli_context=post_cli_context,
             stack_traces=stack_traces,
             tree_metadata=tree_metadata,
@@ -354,6 +363,7 @@ class PDKNagApp(
         context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         default_stack_synthesizer: typing.Optional[_aws_cdk_ceddda9d.IReusableStackSynthesizer] = None,
         outdir: typing.Optional[builtins.str] = None,
+        policy_validation_beta1: typing.Optional[typing.Sequence[_aws_cdk_ceddda9d.IPolicyValidationPluginBeta1]] = None,
         post_cli_context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         stack_traces: typing.Optional[builtins.bool] = None,
         tree_metadata: typing.Optional[builtins.bool] = None,
@@ -367,6 +377,7 @@ class PDKNagApp(
         :param context: Additional context values for the application. Context set by the CLI or the ``context`` key in ``cdk.json`` has precedence. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
         :param default_stack_synthesizer: The stack synthesizer to use by default for all Stacks in the App. The Stack Synthesizer controls aspects of synthesis and deployment, like how assets are referenced and what IAM roles to use. For more information, see the README of the main CDK package. Default: - A ``DefaultStackSynthesizer`` with default settings
         :param outdir: The output directory into which to emit synthesized artifacts. You should never need to set this value. By default, the value you pass to the CLI's ``--output`` flag will be used, and if you change it to a different directory the CLI will fail to pick up the generated Cloud Assembly. This property is intended for internal and testing use. Default: - If this value is *not* set, considers the environment variable ``CDK_OUTDIR``. If ``CDK_OUTDIR`` is not defined, uses a temp directory.
+        :param policy_validation_beta1: Validation plugins to run after synthesis. Default: - no validation plugins
         :param post_cli_context: Additional context values for the application. Context provided here has precedence over context set by: - The CLI via --context - The ``context`` key in ``cdk.json`` - The ``AppProps.context`` property This property is recommended over the ``AppProps.context`` property since you can make final decision over which context value to take in your app. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
         :param stack_traces: Include construct creation stack trace in the ``aws:cdk:trace`` metadata key of all constructs. Default: true stack traces are included unless ``aws:cdk:disable-stack-trace`` is set in the context.
         :param tree_metadata: Include construct tree metadata as part of the Cloud Assembly. Default: true
@@ -380,6 +391,7 @@ class PDKNagApp(
             context=context,
             default_stack_synthesizer=default_stack_synthesizer,
             outdir=outdir,
+            policy_validation_beta1=policy_validation_beta1,
             post_cli_context=post_cli_context,
             stack_traces=stack_traces,
             tree_metadata=tree_metadata,
@@ -450,6 +462,7 @@ class PDKNagApp(
         "context": "context",
         "default_stack_synthesizer": "defaultStackSynthesizer",
         "outdir": "outdir",
+        "policy_validation_beta1": "policyValidationBeta1",
         "post_cli_context": "postCliContext",
         "stack_traces": "stackTraces",
         "tree_metadata": "treeMetadata",
@@ -467,6 +480,7 @@ class PDKNagAppProps(_aws_cdk_ceddda9d.AppProps):
         context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         default_stack_synthesizer: typing.Optional[_aws_cdk_ceddda9d.IReusableStackSynthesizer] = None,
         outdir: typing.Optional[builtins.str] = None,
+        policy_validation_beta1: typing.Optional[typing.Sequence[_aws_cdk_ceddda9d.IPolicyValidationPluginBeta1]] = None,
         post_cli_context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         stack_traces: typing.Optional[builtins.bool] = None,
         tree_metadata: typing.Optional[builtins.bool] = None,
@@ -480,6 +494,7 @@ class PDKNagAppProps(_aws_cdk_ceddda9d.AppProps):
         :param context: Additional context values for the application. Context set by the CLI or the ``context`` key in ``cdk.json`` has precedence. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
         :param default_stack_synthesizer: The stack synthesizer to use by default for all Stacks in the App. The Stack Synthesizer controls aspects of synthesis and deployment, like how assets are referenced and what IAM roles to use. For more information, see the README of the main CDK package. Default: - A ``DefaultStackSynthesizer`` with default settings
         :param outdir: The output directory into which to emit synthesized artifacts. You should never need to set this value. By default, the value you pass to the CLI's ``--output`` flag will be used, and if you change it to a different directory the CLI will fail to pick up the generated Cloud Assembly. This property is intended for internal and testing use. Default: - If this value is *not* set, considers the environment variable ``CDK_OUTDIR``. If ``CDK_OUTDIR`` is not defined, uses a temp directory.
+        :param policy_validation_beta1: Validation plugins to run after synthesis. Default: - no validation plugins
         :param post_cli_context: Additional context values for the application. Context provided here has precedence over context set by: - The CLI via --context - The ``context`` key in ``cdk.json`` - The ``AppProps.context`` property This property is recommended over the ``AppProps.context`` property since you can make final decision over which context value to take in your app. Context can be read from any construct using ``node.getContext(key)``. Default: - no additional context
         :param stack_traces: Include construct creation stack trace in the ``aws:cdk:trace`` metadata key of all constructs. Default: true stack traces are included unless ``aws:cdk:disable-stack-trace`` is set in the context.
         :param tree_metadata: Include construct tree metadata as part of the Cloud Assembly. Default: true
@@ -496,6 +511,7 @@ class PDKNagAppProps(_aws_cdk_ceddda9d.AppProps):
             check_type(argname="argument context", value=context, expected_type=type_hints["context"])
             check_type(argname="argument default_stack_synthesizer", value=default_stack_synthesizer, expected_type=type_hints["default_stack_synthesizer"])
             check_type(argname="argument outdir", value=outdir, expected_type=type_hints["outdir"])
+            check_type(argname="argument policy_validation_beta1", value=policy_validation_beta1, expected_type=type_hints["policy_validation_beta1"])
             check_type(argname="argument post_cli_context", value=post_cli_context, expected_type=type_hints["post_cli_context"])
             check_type(argname="argument stack_traces", value=stack_traces, expected_type=type_hints["stack_traces"])
             check_type(argname="argument tree_metadata", value=tree_metadata, expected_type=type_hints["tree_metadata"])
@@ -513,6 +529,8 @@ class PDKNagAppProps(_aws_cdk_ceddda9d.AppProps):
             self._values["default_stack_synthesizer"] = default_stack_synthesizer
         if outdir is not None:
             self._values["outdir"] = outdir
+        if policy_validation_beta1 is not None:
+            self._values["policy_validation_beta1"] = policy_validation_beta1
         if post_cli_context is not None:
             self._values["post_cli_context"] = post_cli_context
         if stack_traces is not None:
@@ -597,6 +615,17 @@ class PDKNagAppProps(_aws_cdk_ceddda9d.AppProps):
         result = self._values.get("outdir")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def policy_validation_beta1(
+        self,
+    ) -> typing.Optional[typing.List[_aws_cdk_ceddda9d.IPolicyValidationPluginBeta1]]:
+        '''Validation plugins to run after synthesis.
+
+        :default: - no validation plugins
+        '''
+        result = self._values.get("policy_validation_beta1")
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_ceddda9d.IPolicyValidationPluginBeta1]], result)
+
     @builtins.property
     def post_cli_context(
         self,
@@ -763,6 +792,7 @@ def _typecheckingstub__e3e803ce90b5c2282434281a79f47263fc4a4888d6182a6d59c4b475a
     context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
     default_stack_synthesizer: typing.Optional[_aws_cdk_ceddda9d.IReusableStackSynthesizer] = None,
     outdir: typing.Optional[builtins.str] = None,
+    policy_validation_beta1: typing.Optional[typing.Sequence[_aws_cdk_ceddda9d.IPolicyValidationPluginBeta1]] = None,
     post_cli_context: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
     stack_traces: typing.Optional[builtins.bool] = None,
     tree_metadata: typing.Optional[builtins.bool] = None,
